==> grib2io-0.2.0.tar.gz: grib2io-0.2.0/grib2io/tables/section5.py <==
table_5_0 = {
'0':'Grid Point Data - Simple Packing (see Template 5.0)',
'1':'Matrix Value at Grid Point - Simple Packing (see Template 5.1)',
'2':'Grid Point Data - Complex Packing (see Template 5.2)',
'3':'Grid Point Data - Complex Packing and Spatial Differencing (see Template 5.3)',
'4':'Grid Point Data - IEEE Floating Point Data  (see Template 5.4)',
'5-39':'Reserved',
'40':'Grid Point Data - JPEG2000 Compression (see Template 5.40)',
'41':'Grid Point Data - PNG Compression (see Template 5.41)',
'42-49':'Reserved',
'50':'Spectral Data - Simple Packing (see Template 5.50)',
'51':'Spectral Data - Complex Packing (see Template 5.51)',
'52-60':'Reserved',
'61':'Grid Point Data - Simple Packing With Logarithm Pre-processing  (see Template 5.61)',
'62-199':'Reserved',
'200':'Run Length Packing With Level Values  (see Template 5.200)',
'201-49151':'201-49151',
'49152-65534':'Reserved for Local Use',
'65535':'Missing',
}

table_5_1 = {
'0':'Floating Point',
'1':'Integer',
'2-191':'Reserved',
'192-254':'Reserved for Local Use',
'255':'Missing',
}

table_5_2 = {
'0':'Explicit Coordinate Values Set',
'1':'Linear Coordinates  f(1) = C1 f(n) = f(n-1) + C2',
'2-10':'Reserved',
'11':'Geometric Coordinates  f(1) = C1 f(n) = C2 x f(n-1)',
'12-191':'Reserved',
'192-254':'Reserved for Local Use',
'255':'Missing',
}

table_5_3 = {
'0':'Reserved',
'1':'Direction Degrees True',
'2':'Frequency (s-1)',
'3':'Radial Number (2pi/lamda) (m-1)',
'4-191':'Reserved',
'192-254':'Reserved for Local Use',
'255':'Missing',
}

table_5_4 = {
'0':'Row by Row Splitting',
'1':'General Group Splitting',
'2-191':'Reserved',
'192-254':'Reserved for Local Use',
'255':'Missing',
}

table_5_5 = {
'0':'No explicit missing values included within the data values',
'1':'Primary missing values included within the data values',
'2':'Primary and secondary missing values included within the data values',
'3-191':'Reserved',
'192-254':'Reserved for Local Use',
}

table_5_6 = {
'0':'Reserved',
'1':'First-Order Spatial Differencing',
'2':'Second-Order Spatial Differencing',
'3-191':'Reserved',
'192-254':'Reserved for Local Use',
'255':'Missing',
}

table_5_7 = {
'0':'Reserved',
'1':'IEEE 32-bit (I=4 in Section 7)',
'2':'IEEE 64-bit (I=8 in Section 7)',
'3':'IEEE 128-bit (I=16 in Section 7)',
'4-254':'Reserved',
'255':'Missing',
}

table_5_40 = {
'0':'Lossless',
'1':'Lossy',
'2-254':'Reserved',
'255':'Missing',
}

==> grib2io-1.1.0.tar.gz: grib2io-1.1.0/grib2io/tables/section5.py <==
table_5_0 = {
'0':'Grid Point Data - Simple Packing (see Template 5.0)',
'1':'Matrix Value at Grid Point - Simple Packing (see Template 5.1)',
'2':'Grid Point Data - Complex Packing (see Template 5.2)',
'3':'Grid Point Data - Complex Packing and Spatial Differencing (see Template 5.3)',
'4':'Grid Point Data - IEEE Floating Point Data  (see Template 5.4)',
'5-39':'Reserved',
'40':'Grid point data - JPEG 2000 code stream format (see Template 5.40)',
'41':'Grid point data - Portable Network Graphics (PNG) (see Template 5.41)',
'42':'Grid point data - CCSDS recommended lossless compression (see Template 5.42)',
'43-49':'Reserved',
'50':'Spectral Data - Simple Packing (see Template 5.50)',
'51':'Spectral Data - Complex Packing (see Template 5.51)',
'52':'Reserved',
'53':'Spectral data for limited area models - complex packing (see Template 5.53)',
'54-60':'Reserved',
'61':'Grid Point Data - Simple Packing With Logarithm Pre-processing  (see Template 5.61)',
'62-199':'Reserved',
'200':'Run Length Packing With Level Values  (see Template 5.200)',
'201-49151':'Reserved',
'49152-65534':'Reserved for Local Use',
'65535':'Missing',
}

table_5_1 = {
'0':'Floating Point',
'1':'Integer',
'2-191':'Reserved',
'192-254':'Reserved for Local Use',
'255':'Missing',
}

table_5_2 = {
'0':'Explicit Coordinate Values Set',
'1':'Linear Coordinates  f(1) = C1 f(n) = f(n-1) + C2',
'2-10':'Reserved',
'11':'Geometric Coordinates  f(1) = C1 f(n) = C2 x f(n-1)',
'12-191':'Reserved',
'192-254':'Reserved for Local Use',
'255':'Missing',
}

table_5_3 = {
'0':'Reserved',
'1':'Direction Degrees True',
'2':'Frequency (s-1)',
'3':'Radial Number (2pi/lamda) (m-1)',
'4-191':'Reserved',
'192-254':'Reserved for Local Use',
'255':'Missing',
}

table_5_4 = {
'0':'Row by Row Splitting',
'1':'General Group Splitting',
'2-191':'Reserved',
'192-254':'Reserved for Local Use',
'255':'Missing',
}

table_5_5 = {
'0':'No explicit missing values included within the data values',
'1':'Primary missing values included within the data values',
'2':'Primary and secondary missing values included within the data values',
'3-191':'Reserved',
'192-254':'Reserved for Local Use',
}

table_5_6 = {
'0':'Reserved',
'1':'First-Order Spatial Differencing',
'2':'Second-Order Spatial Differencing',
'3-191':'Reserved',
'192-254':'Reserved for Local Use',
'255':'Missing',
}

table_5_7 = {
'0':'Reserved',
'1':'IEEE 32-bit (I=4 in Section 7)',
'2':'IEEE 64-bit (I=8 in Section 7)',
'3':'IEEE 128-bit (I=16 in Section 7)',
'4-254':'Reserved',
'255':'Missing',
}

table_5_40 = {
'0':'Lossless',
'1':'Lossy',
'2-254':'Reserved',
'255':'Missing',
}
